| Title: | The Manhattan++ Plot |
|---|---|
| Description: | This plot integrates annotation into a manhattan plot. The plot is implemented as a heatmap, which is binned using -log10(p-value) and chromosome position. Annotation currently supported is minor allele frequency and gene function high impact variants. |
| Authors: | Chris Grace <[email protected]> |
| Maintainer: | Chris Grace <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.1 |
| Built: | 2026-05-21 07:48:23 UTC |
| Source: | https://github.com/cgrace1978/manhplot |
This plot integrates annotation into a manhattan plot. The plot is implemented as a heatmap, which is binned using -log10(p-value) and chromosome position. Annotation currently supported is minor allele frequency and gene function high impact variants.
The DESCRIPTION file:
| Package: | manhplot |
| Type: | Package |
| Title: | The Manhattan++ Plot |
| Depends: | R (>= 3.4.0) |
| Version: | 1.1 |
| Date: | 2019-05-14 |
| Author: | Chris Grace <[email protected]> |
| Maintainer: | Chris Grace <[email protected]> |
| Description: | This plot integrates annotation into a manhattan plot. The plot is implemented as a heatmap, which is binned using -log10(p-value) and chromosome position. Annotation currently supported is minor allele frequency and gene function high impact variants. |
| License: | GPL (>= 2) |
| RoxygenNote: | 6.1.1 |
| Imports: | reshape2, ggplot2, ggrepel, gridExtra |
| Suggests: | R.utils, testthat |
| URL: | https://github.com/cgrace1978/manhplot/ |
| BugReports: | https://github.com/cgrace1978/manhplot/issues |
| Config/pak/sysreqs: | libicu-dev |
| Repository: | https://cgrace1978.r-universe.dev |
| Date/Publication: | 2023-01-17 15:11:07 UTC |
| RemoteUrl: | https://github.com/cgrace1978/manhplot |
| RemoteRef: | HEAD |
| RemoteSha: | aa1aa5abd2d571a4146c3b15748df9c26a5f1643 |
Index of help topics:
manhplot-package The Manhattan++ Plot manhplusplot Generate the manhattan++ plot
Chris Grace <[email protected]>
Maintainer: Chris Grace <[email protected]>
Generate the manhattan++ plot
manhplusplot(infile, outfile, configfile, snpfile, drawastiff = F, GWS = 5e-08, FDR = 0.001, MAF = 0.05, chrname = "chr", posname = "pos", pvalname = "pvalue", frqname = "maf", conseqname = "conseq", showgenes = F, showrsids = F, pos.split = 3e+06, pval.split = 0.125, max.pval = 20)manhplusplot(infile, outfile, configfile, snpfile, drawastiff = F, GWS = 5e-08, FDR = 0.001, MAF = 0.05, chrname = "chr", posname = "pos", pvalname = "pvalue", frqname = "maf", conseqname = "conseq", showgenes = F, showrsids = F, pos.split = 3e+06, pval.split = 0.125, max.pval = 20)
infile |
Input GWAS summary statistics |
outfile |
Output file prefix for the manhattan++ plot |
configfile |
Configuration file |
snpfile |
Table of SNPs to visualize |
drawastiff |
If TRUE draw a Tiff file, if FALSE draw a PDF file |
GWS |
Genome wise significance pvalue threshold (5E-8 by default) |
FDR |
False discovery Rate pvalue threshold (1E-3 by default) |
MAF |
Minor Allele Frequency threshold |
chrname |
Column name for chromosome in GWAS infile |
posname |
Column name for position in GWAS infile |
pvalname |
Column name for pvalue in GWAS infile |
frqname |
column name for allele frequency in GWAS infile |
conseqname |
column name for variant annotation consequence in GWAS infile |
showgenes |
If T shows known genes as bubbles on main manhattan plot, if F show positions of interest as bubbles |
showrsids |
If showgenes is T, then show the rsids, rather than genes |
pos.split |
The bin lengths for positions |
pval.split |
The bin lengths for pvalues |
max.pval |
The maximum pvalue to display |
For file formats see github page https://github.com/cgrace1978/manhplot
Chris Grace
library(manhplot) infile<-system.file("extdata","cad.add.160614_manhformat.txt.gz",package = "manhplot") configfile<-system.file("extdata","config.txt", package = "manhplot") snpfile<-system.file("extdata","56cad.add.160614.variants.txt", package = "manhplot") manhplusplot(infile = infile,outfile = file.path(tempdir(), "default-plot"), configfile = configfile, snpfile = snpfile)library(manhplot) infile<-system.file("extdata","cad.add.160614_manhformat.txt.gz",package = "manhplot") configfile<-system.file("extdata","config.txt", package = "manhplot") snpfile<-system.file("extdata","56cad.add.160614.variants.txt", package = "manhplot") manhplusplot(infile = infile,outfile = file.path(tempdir(), "default-plot"), configfile = configfile, snpfile = snpfile)